import { useState, useEffect } from "react";
import { Controller, useForm} from 'react-hook-form';
import styles from "./styles.module.scss";
import classNames from "classnames";

export default function Checkbox({ margin, marginTop, marginRight, marginLeft, marginBottom, 
  name, control, errors, rules,
  checked, label,
  style, ...props }) {

  const [isChecked, setIsChecked] = useState(true);
  
  useEffect(() => {
    if(checked){
      setIsChecked(false);
    }
  }, [checked]);

  const {
    register,
  } = useForm({ defaultValues: {check: checked} });



  const classes = classNames({
    [styles.checkbox]: true, 
    [styles.info]: props.info,
    [styles.danger]: props.danger,
    [styles.success]: props.success,
    [styles.warning]: props.warning
  });
  
  const allStyle = {
    ...(margin && { margin }),
    ...(marginTop && { marginTop: marginTop }),
    ...(marginBottom && { marginBottom: marginBottom }),
    ...(marginLeft && { marginLeft: marginLeft }),
    ...(marginRight && { marginRight: marginRight }),
    ...(style && style)
  };
  
  if (!control) {
    return (
      <label className={classes} style={allStyle}>
        <input
          type="checkbox"
          onChange={e => {
            setIsChecked(!e.target.checked)
            console.log(isChecked)
          }}
          checked={!isChecked}
          {...props}
        />
        <span className={styles.checkmark}></span>
        <span>{label}</span>
      </label>
    );
  } else {
    return (
      <>
        <label className={classes} style={allStyle}>
          <Controller
            name={name}
            control={control}
            defaultValue={false} 
            render={({ field }) => (
              <input
                type="checkbox"
                checked={field.checked}
                {...register('check')}
                onChange={(e) => {
                  field.onChange(e.target.checked)
                  console.log(e.target.checked)
                }}
                {...props}
              />
            )}
          />
          <span className={styles.checkmark}></span>
          <span>{label}</span>
        </label>
        {errors[name] && <span>{errors[name].message}</span>}
      </>
    );
  }  
};
