import { Controller } from 'react-hook-form';
import styles from './styles.module.scss';
import classNames from 'classnames';

export default function Input({ margin, marginTop, marginRight, marginLeft, marginBottom, 
  name, control, errors, rules,
  style, type, placeholder, ...props }) {
  
  const classes = classNames({
    [styles.input]: true, 
    [styles.info]: props.info,
    [styles.danger]: props.danger,
    [styles.success]: props.success,
    [styles.warning]: props.warning
  });
  
  const allStyle = {
    ...(margin && { margin }),
    ...(marginTop && { marginTop: marginTop }),
    ...(marginBottom && { marginBottom: marginBottom }),
    ...(marginLeft && { marginLeft: marginLeft }),
    ...(marginRight && { marginRight: marginRight }),
    ...(style && style)
  };
  
  if (!control) {
    return (
      <input 
        className={classes} 
        style={allStyle} 
        placeholder={placeholder} 
        type={type}
        {...props} />);
  } else {
    return (
      <>
        <Controller
          control={control}
          name={name}
          rules={rules}
          render={({ field }) => 
            <input{...field} 
              className={classes} 
              style={allStyle} 
              type={type} 
              placeholder={placeholder}
              {...props} />}
              />
        {errors[name] && <span className={styles.errorMessage}>{errors[name].message}</span>}
      </>
    );
  }
}