import { Controller } from "react-hook-form";
import styles from "./styles.module.scss";
import classNames from "classnames";

export default function Select({ margin, marginTop, marginRight, marginLeft, marginBottom, 
  width, children, style, control, name, rules, errors, ...props }) {
  
  const classes = classNames({
    [styles.select]: true,    
    [styles.info]:    props.info,
    [styles.danger]:  props.danger,
    [styles.success]: props.success,
    [styles.warning]: props.warning
  });

  const allStyle = {
    ...(margin && { margin }),
    ...(marginTop && { marginTop: marginTop }),
    ...(marginBottom && { marginBottom: marginBottom }),
    ...(marginLeft && { marginLeft: marginLeft }),
    ...(marginRight && { marginRight: marginRight }),
    ...(width && { width: width }),
    ...(style && style)
  };
  
  if (!control){
    return (
      <select {...props} className={classes} style={allStyle}>
        {children}
      </select>
    );
  } else {
    return(
      <>
        <Controller
          control={control}
          name={name}
          rules={rules}
          render={({ field }) => (
            <select {...field} {...props} className={classes} style={allStyle}>
              {children}
            </select>
          )}
        />
        {errors[name] && (
          <span className={styles.errorMessage}>{errors[name].message}</span>
        )}
      </>
    )
  }
}