import Button from "@/components/Button";
import Code from "@/components/Code";
import Container from "@/components/Container";
import Message from "@/components/Message";
import Text from "@/components/Text";
import MenuItems from "@/util/menuItems";

export default function ButtonPage(){

  return(
    <Container flexDirection="row">
    <MenuItems />
    <Container margin="1rem" flexGrow="1">
      
      {/* Seção principal */}
      <Text as="h1" margin="0">Componente Button</Text>
      <Text as="p" margin="1rem 0">O componente Button permite apresentar uma mensage de informação. Por padrão, utilza a cor primária definida no tema.</Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem" flexDirection="row">
        <Button title="Button normal">Salvar</Button>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Button from "@/components/Button";

<Button>Salvar</Button>`}
        </Code>
      </Container>

      {/* Seção tamanho */}
      <Text as="p" margin="1rem 0">É possível utilizar as propriedades small, para obter um botão em um tamanho pequeno, e big, para obter um botão em um tamanho grande.</Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem" flexDirection="row" alignItems="center">
        <Button size="small" title="Button small">Salvar</Button>
        <Button title="Button normal">Salvar</Button>
        <Button size="large" title="Button big">Salvar</Button>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Button from "@/components/Button";

<Button size="small">Salvar</Button>
<Button>Salvar</Button>
<Button size="large">Salvar</Button>`}
        </Code>
      </Container>

      {/* Seção tipo */}
      <Text as="p" margin="1rem 0">O componente Button permite definir as seguintes propriedades, que utilizam as cores padrão do tema:</Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem" flexDirection="row">
        <Button type="info">Mais informações</Button>
        <Button type="danger">Deletar</Button>
        <Button type="success">Salvar</Button>
        <Button type="warning">Salvar</Button>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Button from "@/components/Button";

<Button type="info">Mais informações</Button>
<Button type="danger">Deletar</Button>
<Button type="success">Salvar</Button>
<Button type="warning">Salvar</Button>`}
        </Code>
      </Container>

      <Text as="p" margin="1rem 0">O componente Button permite definir as seguintes propriedades, que utilizam as cores padrão do tema:</Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem" flexDirection="row">
        <Button type="outlineInfo">Mais informações</Button>
        <Button type="outlineDanger">Deletar</Button>
        <Button type="outlineSuccess">Salvar</Button>
        <Button type="outlineWarning">Salvar</Button>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Button from "@/components/Button";

<Button type="outlineInfo">Mais informações</Button>
<Button type="outlineDanger">Deletar</Button>
<Button type="outlineSuccess">Salvar</Button>
<Button type="outlineWarning">Salvar</Button>`}
        </Code>
      </Container>

      {/* Seção disabled */}
      <Text as="p" margin="1rem 0">O componente Button permite definir a propriedade disabled:</Text>
        <Container style={{ border: '1px solid black'}} padding=".5rem" flexDirection="row">
          <Button disabled>Salvar</Button>
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
{`import Button from "@/components/Button";

<Button disabled>Salvar</Button>`}
          </Code>
        </Container>   

      {/* Seção icons */}
      <Text as="p" margin="1rem 0">Também é possível adicionar ícones, configurando-os para os tamanhos 8px, no size small, 16px, no size default, e 24px no size large:</Text>
        <Container style={{ border: '1px solid black'}} padding=".5rem" flexDirection="row" alignItems="center" >
          <Button size="small">
            <img src="/icons/check.svg" alt="" />
            Salvar
          </Button>
          <Button>
            <img src="/icons/check.svg" alt="" />
            Salvar
          </Button>
          <Button size="large">
            <img src="/icons/check.svg" alt="" />
            Salvar
          </Button>
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
{`import Button from "@/components/Button";

<Button size="small">
  <img src="/icons/check.svg" alt="" />
  Salvar
</Button>
<Button>
  <img src="/icons/check.svg" alt="" />
  Salvar
</Button>
<Button size="large">
  <img src="/icons/check.svg" alt="" />
  Salvar
</Button>`}
          </Code>
        </Container>              

      {/* Seção customização */}
      <Text as="h2" margin="0" margin_top="1rem">Customização</Text>
      <Text as="p" margin="1rem 0">Também é possível customizar o componente Button utilizando a propriedade style.</Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem" flexDirection="row">
        <Button style={{ backgroundColor: '#000', color: '#FFF', borderColor: '#000'}}>Salvar</Button>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Button from "@/components/Button";

<Button style={{ backgroundColor: '#FFF', color: '#000'}}>Salvar</Button>`}
        </Code>
      </Container>
      <Text as="p" margin="1rem 0">As seguintes propridades podem ser informadas como parâmetro:</Text>
        <ul style={{ marginLeft: '1rem', lineHeight: '2'}}>
          <li>margin</li>
          <li>marginTop</li>
          <li>marginRight</li>
          <li>marginBottom</li>
          <li>marginLeft</li>
        </ul> 
      
        <Text as="p" margin="1rem 0">As seguintes propridades podem ser customizadas no tema:</Text>
        <ul style={{ marginLeft: '1rem', lineHeight: '2'}}>
          <li>buttonFontWeight</li>
          <li>buttonPadding</li>
          <li>buttonMarginRight</li>
          <li>buttonBorderRadius</li>
          <li>buttonBorder</li>
          <li>buttonBorderColor</li>
          <li>buttonSmallPadding</li>
          <li>buttonLargePadding</li>
        </ul> 

    </Container>
  </Container>
  )
}