import { useState } from "react";
import Code from "@/components/Code";
import Container from "@/components/Container";
import Text from "@/components/Text";
import MenuItems from "@/util/menuItems";
import Button from "@/components/Button";
import Modal from "@/components/Modal";

export default function ModalPage(){

  const [isModalOpen, setIsModalOpen] = useState(false);
  const [isModalOpenMaxWidth, setIsModalOpenMaxWidth] = useState(false);

  return(
    <Container flexDirection="row">
    <MenuItems />
    <Container margin="1rem" flexGrow="1">
      
      {/* Seção principal */}
      <Text as="h1" margin="0">Componente Modal</Text>
      <Text as="p" margin="1rem 0">O componente Modal permite ao usuário uma uma janela em cima do conteúdo principal de uma página ou aplicativo,  focada em uma determinada tarefa ou interação. </Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem" flexDirection="row">
        <Button onClick={() => setIsModalOpen(true)}>Abrir Modal</Button>
        <Modal
          isOpen={isModalOpen} 
          onClose={() => setIsModalOpen(false)}
          modalTitle="Título do modal">
          <Text as="p">Lorem ipsum dolor, sit amet consectetur adipisicing elit. Amet, nemo! Laudantium cum debitis.</Text>
          <Container flexDirection="row">
            <Button onClick={() => setIsModalOpen(false)}>Fechar</Button>
          </Container>
        </Modal>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Modal from "@/components/Modal";

// O componente Modal necessita de uma variável para controlar sua visualização
const [isModalOpen, setIsModalOpen] = useState(false);

retun(
  <Button onClick={() => setIsModalOpen(true)}>Abrir Modal</Button>
  <Modal
    isOpen={isModalOpen} 
    onClose={() => setIsModalOpen(false)}
    modalTitle="Título do modal">
    <Text as="p">Lorem ipsum dolor, sit amet consectetur adipisicing elit. Amet, nemo! Laudantium cum debitis.</Text>
    <Container rowReverse>
      <Button onClick={() => setIsModalOpen(false)}>Fechar</Button>
    </Container>
  </Modal>
);`}
        </Code>
      </Container>

      <Text as="p" margin="1rem 0">O componente Modal permite o uso da propriedade maxWidth, que define o tamanho máximo do mesmo.</Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem" flexDirection="row">
        <Button onClick={() => setIsModalOpenMaxWidth(true)}>Abrir Modal</Button>
        <Modal
          maxWidth="200px"
          isOpen={isModalOpenMaxWidth} 
          onClose={() => setIsModalOpenMaxWidth(false)}
          modalTitle="Título do modal">
          <Text as="p">Lorem ipsum dolor, sit amet consectetur adipisicing elit. Amet, nemo! Laudantium cum debitis.</Text>
          <Container flexDirection="rowReverse">
            <Button onClick={() => setIsModalOpenMaxWidth(false)}>Fechar</Button>
          </Container>
        </Modal>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Modal from "@/components/Modal";

// O componente Modal necessita de uma variável para controlar sua visualização
const [isModalOpenMaxWidth, setIsModalOpenMaxWidth] = useState(false);

retun(
  <Button onClick={() => setIsModalOpenMaxWidth(true)}>Abrir Modal</Button>
  <Modal
    maxWidth="200px"
    isOpen={isModalOpenMaxWidth} 
    onClose={() => setIsModalOpenMaxWidth(false)}
    modalTitle="Título do modal">
    <Text as="p">Lorem ipsum dolor, sit amet consectetur adipisicing elit. Amet, nemo! Laudantium cum debitis.</Text>
    <Container flexDirection="rowReverse">
      <Button onClick={() => setIsModalOpenMaxWidth(false)}>Fechar</Button>
    </Container>
  </Modal>
);`}
        </Code>
      </Container>
    </Container>
  </Container>
  )
}