import { useForm } from "react-hook-form";
import Code from "@/components/Code";
import Container from "@/components/Container";
import Text from "@/components/Text";
import MenuItems from "@/util/menuItems";
import Checkbox from "@/components/Checkbox";
import Form from "@/components/Form";
import FormGroup from "@/components/FormGroup";
import FormItem from "@/components/FormItem";
import Radio from "@/components/Radio";

export default function RadioPage(){

  const { control, handleSubmit, formState: { errors }} = useForm();

  const onSubmit = (data) => {
    console.log(data);
  }

  return(
    <Container flexDirection="row">
    <MenuItems />
    <Container margin="1rem" flexGrow="1">
      
      {/* Seção principal */}
      <Text as="h1" margin="0">Componente Radio</Text>
      <Text as="p" margin="1rem 0">O componente Radio permite ao usuário seleção única. Por padrão, utilza a cor primária definida no tema</Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem">
        <Radio label="Opção 1" name="opcao" />
        <Radio label="Opção 2" name="opcao" />
        <Radio label="Opção 3" name="opcao" />
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Radio from "@/components/Radio";

<Radio label="Opção 1" name="opcao" />
<Radio label="Opção 2" name="opcao" />
<Radio label="Opção 3" name="opcao" />"`}
        </Code>
      </Container>

{/* Seção customização */}
{/* <Text as="h2" margin="0" margin_top="1rem">Customização</Text>
        <Text as="p" margin="1rem 0">Também é possível customizar o componente Checkbox utilizando a propriedade style.</Text>
        <Container style={{ border: '1px solid black'}} padding=".5rem">
          <Checkbox label="Concordo com os termos" marginTop="1rem" marginLeft="1rem" />
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
{`import Checkbox from "@/components/Checkbox";

<Checkbox label="Concordo com os termos" marginTop="1rem" marginLeft="1rem" />`}
          </Code>
        </Container>
        <Text as="p" margin="1rem 0">As seguintes propridades podem ser informadas como parâmetro:</Text>
        <ul style={{ marginLeft: '1rem', lineHeight: '2'}}>
          <li>margin</li>
          <li>marginTop</li>
          <li>marginRight</li>
          <li>marginBottom</li>
          <li>marginLeft</li>
        </ul>  */}

      {/* Seção React Hook Form */}
      <Text as="h2" margin="0" margin_top="1rem">Compatibilidade com React Hook Form</Text>
        <Text as="p" margin="1rem 0">O componente Input é compatível com o React Hook Form. Pressione enter no input para visualizar a validação.</Text>
        <Container style={{ border: '1px solid black' }}>
          <Form onSubmit={handleSubmit(onSubmit)}>
            <FormGroup>
              <FormItem>
                <Radio label="Opção 1" name="opcao" control={control} errors={errors} />
                <Radio label="Opção 2" name="opcao" control={control} errors={errors}/>
                <Radio label="Opção 3" name="opcao" control={control} errors={errors}/>
              {/* <Button>Enviar</Button> */}
              </FormItem>
            </FormGroup>
          </Form>
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Checkbox from "@/components/Checkbox";

<Checkbox
  label="Concordo com os termos"
  name="termos"
  control={control}
  errors={errors} />"`}
        </Code>
      </Container>        
    </Container>
  </Container>
  )
}