import Code from "@/components/Code";
import Container from "@/components/Container";
import Select from "@/components/Select";
import Option from "@/components/Option";
import Text from "@/components/Text";
import MenuItems from "@/util/menuItems";
import Form from "@/components/Form";
import FormGroup from "@/components/FormGroup";
import FormItem from "@/components/FormItem";
import { useForm } from "react-hook-form";
import Button from "@/components/Button";

export default function SelectPage(){

  const { control, handleSubmit, formState: { errors }} = useForm();

  const onSubmit = (data) => {
    alert(`Estado selecionado: ${data.uf}`);
  }

  return(
    <Container flexDirection="row">
    <MenuItems />
    <Container margin="1rem" flexGrow="1">
      
      {/* Seção principal */}
      <Text as="h1" margin="0">Componente Select</Text>
      <Text as="p" margin="1rem 0">O componente Select permite, em combinação com o componente Option, uma seleção única em uma caixa suspensa.</Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem">
        <Select id="estados">
          <Option value="AC">Acre</Option>
          <Option value="AM">Amazonas</Option>
          <Option value="RO">Rondônia</Option>
        </Select>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Select from "@/components/Select
import Option from "@/components/Option 

<Select id="estados">
  <Option value="AC">Acre</Option>
  <Option value="AM">Amazonas</Option>
  <Option value="RO">Rondônia</Option>
</Select>`}
        </Code>
      </Container>

        {/* Seção customização */}
        <Text as="h2" margin="0" margin_top="1rem">Customização</Text>
        <Text as="p" margin="1rem 0">Também é possível customizar o componente input utilizando a propriedade style.</Text>
        <Container style={{ border: '1px solid black'}} padding=".5rem">
          <Select id="estados" style={{ border: '1px blue dotted' }} width="100px">
            <Option value="AC">Acre</Option>
            <Option value="AM">Amazonas</Option>
            <Option value="RO">Rondônia</Option>
          </Select>
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
{`import Select from "@/components/Select"
import Option from "@/components/Option"

<Select id="estados" style={{ border: '1px blue dotted' }} width="100px">
  <Option value="AC">Acre</Option>
  <Option value="AM">Amazonas</Option>
  <Option value="RO">Rondônia</Option>
</Select>`}
          </Code>
        </Container>
        <Text as="p" margin="1rem 0">As seguintes propridades podem ser informadas como parâmetro:</Text>
        <ul style={{ marginLeft: '1rem', lineHeight: '2'}}>
          <li>margin</li>
          <li>marginTop</li>
          <li>marginRight</li>
          <li>marginBottom</li>
          <li>marginLeft</li>
          <li>width</li>
        </ul>       

      {/* React Hook Form */}
      <Text as="h2" margin="0" margin_top="1rem">Compatibilidade com React Hook Form</Text>
      <Text as="p" margin="1rem 0">O componente Select permite, em combinação com o componente Option, uma seleção única em uma caixa suspensa.</Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem">
        <Form>
          <FormGroup>
            <FormItem>
              <Select 
                control={control}
                name="uf"
                rules={{ required: "O estado é obrigatório" }}
                errors={errors}>
                <Option value="AC">Acre</Option>
                <Option value="AM">Amazonas</Option>
                <Option value="RO">Rondônia</Option>
              </Select>
            </FormItem>
            <FormItem>
              <Button onClick={handleSubmit(onSubmit)}>Enviar</Button>
            </FormItem>
          </FormGroup>
        </Form>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import Select from "@/components/Select";
import Option from "@/components/Option";";

<Select 
  control={control}
  name="uf"
  rules={{ required: true }}
  errors={errors}>
  <Option value="AC">Acre</Option>
  <Option value="AM">Amazonas</Option>
  <Option value="RO">Rondônia</Option>
</Select>`}
        </Code>
      </Container>
  

     </Container>
  </Container>
  )
}